Reference class

One place a package is mentioned in the project.

Constructors

Reference(String file, int line)
const

Properties

file String
Path relative to the project root, with forward slashes.
final
hashCode int
The hash code for this object.
no setterinherited
line int
1-based line number.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited